Create a prompt for equivalent mutant detection
Source:R/openai.R
create_equivalent_mutant_prompt.RdGenerates a well-formatted prompt for the OpenAI API to analyze if mutants are equivalent to the original code.
R/openai.R
create_equivalent_mutant_prompt.RdGenerates a well-formatted prompt for the OpenAI API to analyze if mutants are equivalent to the original code.